import { ApplicationDataSource } from '../database/datasource.js';
import { LtiResourceStudent, LtiResourceStudentRoleMapModel } from '../database/model.js';
export class LTIResourceStudent {
    resource_id;
    student_model;
    role_mapping_models;
    student_id;
    // #region Initializers
    constructor(resource_id, student_model, role_mapping_models) {
        this.resource_id = resource_id;
        this.student_model = student_model;
        this.role_mapping_models = role_mapping_models;
        this.student_id = student_model.id;
    }
    static async newStudent(resource_id, student) {
        const role_mappings = await ApplicationDataSource.manager.findBy(LtiResourceStudentRoleMapModel, { student });
        return new LTIResourceStudent(resource_id, student, role_mappings);
    }
    static async byId({ student_id, resource_id }) {
        const student = await ApplicationDataSource.manager.findOneByOrFail(LtiResourceStudent, {
            resource: { id: resource_id },
            external_id: student_id,
        });
        return this.newStudent(resource_id, student);
    }
    static async list({ resource_id }) {
        const students = await ApplicationDataSource.manager.findBy(LtiResourceStudent, {
            resource: { id: resource_id },
        });
        return Promise.all(students.map(student => this.newStudent(resource_id, student)));
    }
    // #endregion
    get email() {
        return this.student_model.email;
    }
    get name() {
        return this.student_model.name;
    }
    get role_mappings() {
        return this.role_mapping_models.map(role => ({
            role: role.role,
            device: role.device,
        }));
    }
    async set_role_mapping(p) {
        if (p.device === 'GROUP') {
            await ApplicationDataSource.manager.delete(LtiResourceStudentRoleMapModel, {
                student: { id: this.student_id },
                role: p.role,
            });
        }
        {
            await ApplicationDataSource.manager.upsert(LtiResourceStudentRoleMapModel, {
                role: p.role,
                student: { id: this.student_id },
                device: p.device,
            }, ['student', 'role']);
        }
    }
}
//# sourceMappingURL=lti_resource_student.js.map